//=============================================================================
// TO_SPHCB_CIA.
//=============================================================================
// Special mission behaviors.
// Disable the retina scaner, modify door behavior and catch the final
// console timer message to spawn end game triggers.
//=============================================================================
// Programmed by Mathieu 'EMH_Mark3' Mallet for Tactical Ops
// 14/11/2002
//=============================================================================

class TO_SPHCB_CIA expands TO_SP_HardCodedBehaviors;

var	TO_SinglePlayerGame		game;
var	TO_SP_HCBTrigger		Alarms[4];
var TO_SP_SparksGenerator	sparksgen;

function Initialise(TO_SinglePlayerGame myGame) {
	local TO_RoundWinning			winActor;
	local TO_ConsoleTimer			console;
	local TO_MessageDisplay			message;
	local TO_TransmitTriggerMessage	trigger;
	local Mover						mover;
	local TO_SP_Pathnode			aPathnode;
	
	game = myGame;
	tag = 'T2_win';

	foreach allactors(class'TO_RoundWinning', winActor)
		winActor.tag = 'TO_SP_InvalidTag'; // Used to prevent the round winning actor from being activated

	// Disable the retinal scanner
	console = TO_ConsoleTimer(game.FindActor("TO_ConsoleTimer0"));
	console.CTDuration = 5;
	console.EventCompleted = 'TO_SP_T1_done';

	// Change the retinal scanner message
	message = TO_MessageDisplay(game.FindActor("TO_MessageDisplay0"));
	message.message = "Retinal scan failed -- Unauthorized user!";
	message.tag = 'TO_SP_T1_done';

	// Change the door's trigger trigger transmitter so it doesn't reset the round when used
	trigger = TO_TransmitTriggerMessage(game.FindActor("TO_TransmitTriggerMessage0"));
	trigger.tag = 'TO_SP_InvalidTag';

	// Change the door's tag so it opens when the console is used
	mover = Mover(game.FindActor("Mover7"));
	mover.tag = 'T2_win';

	// Spawn additionnal pathnodes
	aPathnode = Spawn(class'TO_SP_Pathnode',,'Pathnode3',		vect(-1061.427368,	709.243591,		-2953.862305));
	warn("Spawned pathnode with name " $ aPathnode.name);
	aPathnode = Spawn(class'TO_SP_Pathnode',,'Pathnode5',		vect(67.182465,	-672.130493,	-2953.982422));
	warn("Spawned pathnode with name " $ aPathnode.name);
	aPathnode = Spawn(class'TO_SP_Pathnode',,'Pathnode24',	vect(1425.747070,	-281.733856,	-2921.948975));
	warn("Spawned pathnode with name " $ aPathnode.name);
	aPathnode = Spawn(class'TO_SP_Pathnode',,'Pathnode21',	vect(1427.561523,	27.994537,		-2921.948975));
	warn("Spawned pathnode with name " $ aPathnode.name);
	aPathnode = Spawn(class'TO_SP_Pathnode',,'Pathnode4',		vect(1296.458252,	-164.051788,	-2953.982422));
	warn("Spawned pathnode with name " $ aPathnode.name);

	// Spawn alarm interceptors
	Alarms[0] = spawn(class'TO_SP_HCBTrigger');
	Alarms[0].messageNumber = 1;
	Alarms[0].tag = 'md4';

	Alarms[1] = spawn(class'TO_SP_HCBTrigger');
	Alarms[1].messageNumber = 1;
	Alarms[1].tag = 'md2';

	Alarms[2] = spawn(class'TO_SP_HCBTrigger');
	Alarms[2].messageNumber = 1;
	Alarms[2].tag = 'md1';

	// Disable the alarm on the left side of the building
	mover = Mover(game.FindActor("Mover5"));
	mover.tag = 'TO_SP_InvalidTag';

	// Spawn sparks generator
	sparksgen = spawn(class'TO_SP_SparksGenerator',,, vect(-851.408203,	101.553200,	-3990.728027), rot(6048, 16448, 0));
	
}

// Mainframe has been hax0red!
function Trigger( actor Other, pawn EventInstigator ) {
	local TO_ConsoleTimer			console;

	// Set alarm sound on the console timer
	console = TO_ConsoleTimer(game.FindActor("TO_ConsoleTimer3"));
	console.AmbientSound = Sound(DynamicLoadObject("AmbModern.Looping.alarm1", class'Sound'));

	game.SpawnSpecialBots();
	game.SpawnEndGameTriggers();
	game.SpecialTriggersMSG();
}

function PostRestartRound() {
	local mover mover;
	local TO_ConsoleTimer			console;

	// reset laser barrier position
	foreach AllActors( class 'Mover', mover, 'T2_win' )
		mover.Trigger( None, None );


	// Reset alarm sound on the console timer
	console = TO_ConsoleTimer(game.FindActor("TO_ConsoleTimer3"));
	console.AmbientSound = none;

}

// Make every bot in the map attack the player when the alarms are triggered
function TriggerMessage1(actor Other, pawn EventInstigator) {
	local pawn	PawnLink;
	if (EventInstigator.IsA('s_bot')) // && s_Bot(EventInstigator).PlayerReplicationInfo.Team != SinglePlayerDefinition.PlayerTeam)
		return;
	
	for ( PawnLink=Level.PawnList; PawnLink!=None; PawnLink=PawnLink.nextPawn )	{
		if ( (PawnLink.PlayerReplicationInfo != None) && !PawnLink.PlayerReplicationInfo.bWaitingPlayer ) {
			if ( ((s_Bot(PawnLink) != None) && (!s_Bot(PawnLink).bNotPlaying))) { // Is a bot
				s_Bot(PawnLink).SetOrders('Follow', game.GetPlayer(), false);
			}
		}
	}
	
}

defaultproperties
{
}
