//=============================================================================
// TO_SPHCB_Verdon.
//=============================================================================
// Special mission behaviors.
// Used to prevent player from receiving the bomb at beginning of the level,
// to spawn c4 in the level and to disable one of the bomb spots.
//=============================================================================
// Programmed by Mathieu 'EMH_Mark3' Mallet for Tactical Ops
// 12/11/2002
//=============================================================================

class TO_SPHCB_Verdon expands TO_SP_HardCodedBehaviors;

var	TO_SinglePlayerGame		game;
var bool					bSpecialEffectRunning;

var localized string		DisabledDoorTriggerText;
var localized string		DisabledElevatorTriggerText;
var localized string		DisabledDoorTriggerTextInit;

// Special effect variables
var TO_SP_WaterSheet		watersheet[5];
var vector					StartingWaterPosition;
var vector					FinalWaterPosition;
var float					WaterRisingSpeed;

var vector					WaterSpawnerLocation;
var rotator					WaterSpawnerRotation;
var TO_SP_WaterSpawner		waterspawner;

var float					time;

function Initialise(TO_SinglePlayerGame myGame) {
	local s_ZoneControlPoint	zone;
	local s_trigger				trigger;
	
	game = myGame;

	// Disable one of the bombing spots
	foreach allactors(class's_ZoneControlPoint', zone)
		if (zone.name == 's_ZoneControlPoint5')
			zone.bBombingZone = false;

	// Disable top elevator doors' triggers
	trigger = s_trigger(game.FindActor("s_trigger15"));
	trigger.Message = DisabledDoorTriggerTextInit;
	trigger.event = 'TO_SP_InvalidTag';

	trigger = s_trigger(game.FindActor("s_trigger14"));
	trigger.Message = DisabledDoorTriggerTextInit;
	trigger.event = 'TO_SP_InvalidTag';
}

function PreRestartRound() {
	local s_C4			c4;
	local s_trigger		trigger;
	local mover			mover;
	
	// Delete the extra c4 in the level
	foreach allactors(class's_SWAT.s_C4', c4)
		c4.Destroy();

	// Restore top doors movers
	mover = mover(game.FindActor("Mover10"));
	mover.bUseTriggered = true;

	mover = mover(game.FindActor("Mover11"));
	mover.bUseTriggered = true;

	// Restore top elevator doors
	/*mover = mover(game.FindActor("Mover12"));
	mover.bUseTriggered = true;

	mover = mover(game.FindActor("Mover17"));
	mover.bUseTriggered = true;*/

	// Restore other elevator doors
	mover = mover(game.FindActor("Mover24"));
	mover.bUseTriggered = true;

	mover = mover(game.FindActor("Mover25"));
	mover.bUseTriggered = true;


	// Restore top doors triggers
	trigger = s_trigger(game.FindActor("s_trigger12"));
	trigger.Message = "";
	trigger.event = 'Door_8';

	trigger = s_trigger(game.FindActor("s_trigger13"));
	trigger.Message = "";
	trigger.event = 'Door_9';

	// Restore top elevator doors
	/*trigger = s_trigger(game.FindActor("s_trigger15"));
	trigger.Message = "";
	trigger.event = 'Door_11';

	trigger = s_trigger(game.FindActor("s_trigger14"));
	trigger.Message = "";
	trigger.event = 'Door_10';*/

	// Restore other elevator doors
	trigger = s_trigger(game.FindActor("s_trigger8"));
	trigger.Message = "";
	trigger.event = 'dispboven1a';

	DeleteSpecialEffects();
}

function PostRestartRound() {
	local s_C4		c4;
	
	// Spawn a new c4 actor in the level
	C4 = spawn(class'TO_SP_C4',,, vect(-722,-4037,-695));
	//C4 = spawn(class'TO_SP_C4',,, game.FindActor("LiftCenter1").location);
	if (C4 != None)
		C4.SetPhysics(PHYS_Falling);
}

function bool ShouldGiveBomb() {
	return false;
}

function C4Planted(vector PlantLocation, s_ExplosiveC4 PlantedC4) {
	local s_trigger		trigger;
	local mover			mover;

	// Close top doors
	mover = mover(game.FindActor("Mover10"));
	if (mover.keynum == 1)
		mover.Trigger(self, game.GetPlayer());
	mover.bUseTriggered = false;

	mover = mover(game.FindActor("Mover11"));
	if (mover.keynum == 1)
		mover.Trigger(self, game.GetPlayer());
	mover.bUseTriggered = false;

	// Close top elevator doors
	/*mover = mover(game.FindActor("Mover12"));
	if (mover.keynum == 1)
		mover.Trigger(self, game.GetPlayer());
	mover.bUseTriggered = false;

	mover = mover(game.FindActor("Mover17"));
	if (mover.keynum == 1)
		mover.Trigger(self, game.GetPlayer());
	mover.bUseTriggered = false;*/

	// Close other elevator doors
	mover = mover(game.FindActor("Mover24"));
	if (mover.keynum == 1)
		mover.Trigger(self, game.GetPlayer());
	mover.bUseTriggered = false;

	mover = mover(game.FindActor("Mover25"));
	if (mover.keynum == 1)
		mover.Trigger(self, game.GetPlayer());
	mover.bUseTriggered = false;


	// Disable top doors' triggers
	trigger = s_trigger(game.FindActor("s_trigger12"));
	trigger.Message = DisabledDoorTriggerText;
	trigger.event = 'TO_SP_InvalidTag';

	trigger = s_trigger(game.FindActor("s_trigger13"));
	trigger.Message = DisabledDoorTriggerText;
	trigger.event = 'TO_SP_InvalidTag';

	// Disalbe top elevator doors' triggers
	/*trigger = s_trigger(game.FindActor("s_trigger15"));
	trigger.Message = DisabledDoorTriggerText;
	trigger.event = 'TO_SP_InvalidTag';

	trigger = s_trigger(game.FindActor("s_trigger14"));
	trigger.Message = DisabledDoorTriggerText;
	trigger.event = 'TO_SP_InvalidTag';*/
	
	// Disable other elevator doors' trigger
	trigger = s_trigger(game.FindActor("s_trigger8"));
	trigger.Message = DisabledElevatorTriggerText;
	trigger.event = 'TO_SP_InvalidTag';

}

function C4ExplodedPlus(bool bExplodedInBombingZone, Actor BombingZone) {
	SpawnSpecialEffects(BombingZone.location);
}

function DeleteSpecialEffects() {
	local int					i;

	Disable( 'Tick' );

	bSpecialEffectRunning = false;

	for (i = 0; i < 5; i++)
		if (watersheet[i] != none) {
			watersheet[i].destroy();
			watersheet[i] = none;
		}

	if (waterspawner != none) {
		waterspawner.destroy();
		waterspawner = none;
	}

}

function SpawnSpecialEffects(vector BombingZone) {
	local int		i;

	watersheet[0] = spawn(class'TO_SP_WaterSheet',,, StartingWaterPosition);
	watersheet[0].texture = WetTexture(DynamicLoadObject("richrig.Water.Wateranim1", class'WetTexture'));
	watersheet[0].bUnlit = true;

	watersheet[1] = spawn(class'TO_SP_WaterSheet',,, StartingWaterPosition + vect(-1,0,0) * watersheet[0].drawscale * 102.2);
	watersheet[1].texture = WetTexture(DynamicLoadObject("richrig.Water.Wateranim1", class'WetTexture'));
	watersheet[1].bUnlit = true;

	watersheet[2] = spawn(class'TO_SP_WaterSheet',,, StartingWaterPosition + vect(0,1,0) * watersheet[0].drawscale * 102.2);
	watersheet[2].texture = WetTexture(DynamicLoadObject("richrig.Water.Wateranim1", class'WetTexture'));
	watersheet[2].bUnlit = true;

	watersheet[3] = spawn(class'TO_SP_WaterSheet',,, StartingWaterPosition + vect(-1,1,0) * watersheet[0].drawscale * 102.2);
	watersheet[3].texture = WetTexture(DynamicLoadObject("richrig.Water.Wateranim1", class'WetTexture'));
	watersheet[3].bUnlit = true;

	watersheet[4] = spawn(class'TO_SP_WaterSheet',,, StartingWaterPosition + vect(-0.5,2,0) * watersheet[0].drawscale * 102.2);
	watersheet[4].texture = WetTexture(DynamicLoadObject("richrig.Water.Wateranim1", class'WetTexture'));
	watersheet[4].bUnlit = true;

	time = 0;

	waterspawner = spawn(class'TO_SP_WaterSpawner',,, WaterSpawnerLocation, WaterSpawnerRotation);

	for (i = 0; i < 5; i++) {
		watersheet[i].SetCollision(true, true, false);
		watersheet[i].SetCollisionSize(2169.000000, 20.00000);
	}

	bSpecialEffectRunning = true;
	Enable( 'Tick' );
}

function Tick(float DeltaTime) {
	local float	position;
	local int		i;

	if (!bSpecialEffectRunning) {
		Disable( 'Tick' );
		return;
	}

	time += DeltaTime;
	
	position = StartingWaterPosition.z + (FinalWaterPosition.z - StartingWaterPosition.z) * (1 - exp(time * WaterRisingSpeed));

	for (i = 0; i < 5; i++)
		watersheet[i].SetLocation(watersheet[i].location + vect(0,0,1) * (Position - watersheet[i].location.z));

}

defaultproperties
{
     DisabledDoorTriggerText="It locked automatically."
     DisabledElevatorTriggerText="Power to the elevator has been cut."
     DisabledDoorTriggerTextInit="It's locked."
     StartingWaterPosition=(X=236.820007,Y=-250.039993,Z=-826.000000)
     FinalWaterPosition=(X=236.820007,Y=-250.039993,Z=242.000000)
     WaterRisingSpeed=-0.100000
     WaterSpawnerLocation=(X=-851.882568,Y=-1839.691284,Z=1123.077148)
     WaterSpawnerRotation=(Pitch=1392,Yaw=16320)
}
