//=============================================================================
// TO_SP_BombingPoint.
//=============================================================================
// Is a bomb spot that can only be used once per round. Also, two events are
// used: EventC4Planted, called when the c4 is planted on this bomb spot, and
// EventC4Exploded, called when the c4 has successfully been detonated.
// The C4CountdownTime sets the time it takes for the C4 to explode.
// Note that the lower the number, the less precise the countdown is.
//=============================================================================
// Programmed by Mathieu 'EMH_Mark3' Mallet for Tactical Ops
// 19/08/2002
//=============================================================================

class TO_SP_BombingPoint extends s_ZoneControlPoint;

var()		int		C4CountdownTime;
var(Events) name	EventC4Planted;
var(Events) name	EventC4Exploded;


function BeginPlay () {
	bBombingZone = true;
}

auto state() IsResetableActor {

}

function DisableBombSpot() {
	local actor A;
	bBombingZone = false;
	
	// Broadcast the Trigger message to actors matching the event tab
	//log("TO_SP_BombingPoint::DisableBombSpot: Checking for event...");
	if( EventC4Planted != '' ) {
		//log("TO_SP_BombingPoint::DisableBombSpot: Passing each matching actor...");
		foreach AllActors( class 'Actor', A, EventC4Planted ) {
			//log("TO_SP_BombingPoint::DisableBombSpot: Triggering actor " $ string(A.name));
			A.Trigger( Self, None );
		}
	}
}

function BombDetonated() {
	local actor A;

	// Broadcast the Trigger message to actors matching the event tab
	//log("TO_SP_BombingPoint::BombDetonated: Checking for event...");
	if( EventC4Exploded != '' ) {
		//log("TO_SP_BombingPoint::BombDetonated: Passing each matching actor...");
		foreach AllActors( class 'Actor', A, EventC4Exploded ) {
			//log("TO_SP_BombingPoint::BombDetonated: Triggering actor " $ string(A.name));
			A.Trigger( Self, None );
		}
	}
}

defaultproperties
{
     C4CountdownTime=15
     bBuyPoint=False
     bRescuePoint=False
     bHomeBase=False
     bBombingZone=True
     InitialState=IsResetableActor
}
