//=============================================================================
// TO_SP_GUITabScores.
//=============================================================================
// Displays mission status (instead of scoreboard)
//=============================================================================
// Programmed by Mathieu 'EMH_Mark3' Mallet for Tactical Ops
// 02/11/2002
//=============================================================================

class TO_SP_GUITabScores expands TO_GUIBaseTab;
 
/*
========================
   properties
========================
*/

	// lists
	var string				EnemyCasualties[128];
	var int					LastEnemyCasualty;
	var string				TeamCasualties[128];
	var int					LastTeamCasualty;
	var bool				bInitialized;
	var bool				bUseSimpleEnemyAnalysis;
	var TO_SinglePlayerGame	Game;

	var color				ColorBest;
	var color				ColorNormal;
	var color				ColorWorse;


/*
========================
   localized
========================
*/

	var localized string	TextTitle;
	var localized string	TextHint;


	var localized string	TextFriendlyCasualties;
	var localized string	TextEnemyCasualties;

	var localized string	TextEstimatedEnemies;
	var localized string	TextEnemyAnalysis;
	var localized string	TextEnemyInLevel;
	var localized string	TextEnemyRemaining;

	var localized string	TextNone;
	var localized string	TextTotal;
	var localized string	TextNoPercentage;
	
	var localized string	TextAccuracy;
	var localized string	TextShotsFired;
	var localized string	TextHeadshots;
	var localized string	TextBodyHits;
	var localized string	TextLegsHits;
	var localized string	TextTeamHits;
	var localized string	TextMisses;
	var localized string	TextOverall;

	var localized string	TextPlayerStatus;
	var localized string	TextConditionSF;
	var localized string	TextConditionTerr;
	var localized string	TextRemainingHelmet;
	var localized string	TextRemainingBody;
	var localized string	TextRemainingLegs;
	var localized string	TextPlayerDeadSF;
	var localized string	TextPlayerDeadTerr;

/*
================================================================================================================================================
   methods (engine)
================================================================================================================================================
*/

////////////////////
// Created
////////////////////

simulated function Created () {
	Super.Created();
	Hint = TextHint;
	ResetScoreBoard();

	ColorBest = OwnerInterface.Design.ColorGreen;
	ColorNormal = OwnerInterface.Design.ColorSuperwhite;
	ColorWorse = OwnerInterface.Design.ColorRed;

	Game = TO_SinglePlayerGame(GetPlayerOwner().Level.Game);
	if (Game == none) {
		warn("Could not find TO_SinglePlayerGame actor!");
		assert(false);
	}

	bUseSimpleEnemyAnalysis = game.bUseSimpleEnemyAnalysis;
}


////////////////////
// Close
////////////////////

simulated function Close (optional bool bByParent) {
	Super.Close(bByParent);
}


////////////////////
// BeforePaint
////////////////////

simulated function BeforePaint (Canvas Canvas, float x, float y) {
	Super.BeforePaint(Canvas, x, y);

	if (!bDraw) {
		return;
	}

	Title = TextTitle;
}


////////////////////
// Paint
////////////////////

simulated function Paint (Canvas Canvas, float x, float y) {
	if (!bDraw)	{
		return;
	}

	
	// background
	if (OwnerHud.bDrawBackground) {
		Super.Paint(Canvas, x, y);
	}

	TO_MissionStatus_DrawStuff(Canvas);

}


/*
================================================================================================================================================
   methods (exported)
================================================================================================================================================
*/

////////////////////
// OwnerTimer
////////////////////

simulated function OwnerTimer ()
{
	//bShowMode = !bShowMode;
}


////////////////////
// ToggleMode
////////////////////

simulated function OwnerToggleMode ()
{
	/*switch (SortMode)
	{
		case SM_SCOREALL:		SortMode = SM_SCOREGROUP; AltHint = TextScoresSort@TextScoresScoregroup; break;
		case SM_SCOREGROUP:		SortMode = SM_KILLRATIO; AltHint = TextScoresSort@TextScoresKillratio; break;
		case SM_KILLRATIO:		SortMode = SM_PING;  AltHint = TextScoresSort@TextScoresPing; break;
		case SM_PING:			SortMode = SM_TIME; AltHint = TextScoresSort@TextScoresTime; break;
		default:				SortMode = SM_SCOREALL; AltHint = TextScoresSort@TextScoresScore;
	}

	OwnerInterface.bAltHint = true;*/
}


simulated function ResetScoreBoard() {
	LastTeamCasualty = -1;
	LastEnemyCasualty = -1;
}

simulated function Tool_DrawText (Canvas Canvas, string text, float x, float y, float w, out float xl, out float yl) {
	local float		oldorigx, oldclipx;

	oldorigx = Canvas.OrgX;
	oldclipx = Canvas.ClipX;

	Canvas.OrgX = x;
	Canvas.ClipX = w;

	Canvas.SetPos(0, y);
	Canvas.StrLen(text, xl, yl);
	Canvas.DrawText(text, false);

	Canvas.OrgX = oldorigx;
	Canvas.ClipX = oldclipx;
}

simulated function TO_MissionStatus_DrawStuff(Canvas Canvas) {
	local float									y, xl, yl, oneline, ybox, y2cols;
	local TournamentGameReplicationInfo			gri;
	local TO_SinglePlayerGame					game;
	local string								currentText;
	local float									col1, col1t, col1twidth, col1twidth2, col1l;
	local float									col2, col2t, col2twidth, col2l;
	local int									i, EnemiesSpawned, EnemiesAlive, Efficiency;

	gri = TournamentGameReplicationInfo(OwnerPlayer.GameReplicationInfo);
	y = Top + Padding[Resolution];

	game = TO_SinglePlayerGame(GetPlayerOwner().Level.Game);
	if (game == none) {
		Canvas.StrLen("Could not find TO_SinglePlayerGame actor !!", xl, yl);
		Canvas.DrawColor = OwnerInterface.Design.ColorSuperwhite;
		Canvas.SetPos(Left + Width*0.5 - 0.5*xl, Top + Height/2 - yl / 2);
		Canvas.DrawText("Could not find TO_SinglePlayerGame actor !!");
		return;
	}

	col1 = Left + Padding[resolution];
	col1t = Left + Padding[resolution] * 3;
	col1twidth = Left + Width - Padding[resolution] - (Left + Padding[resolution] * 3);
	col1twidth2 = Left + Width - Padding[resolution] * 4 - (Left + Width / 2);
	col1l = Left + Width / 2 - Padding[resolution];
	col2 = Left + Width / 2 + Padding[resolution];
	col2t = Left + Width / 2 + Padding[resolution] * 3;
	col2twidth = Left + Width - Padding[resolution] - (Left + Width / 2 + Padding[resolution] * 3);
	col2l = Left + Width - Padding[resolution];	
	
	OwnerInterface.Design.SetScoreboardFont(Canvas);
	Canvas.StrLen("abcABC", xl, oneline);

	Canvas.Style = OwnerHud.ERenderStyle.STY_NORMAL;


	///////////////////////////////////
	// Draw Team Casualties
	///////////////////////////////////

	OwnerInterface.Design.SetHeadlineFont(Canvas);
	currentText = TextFriendlyCasualties;
	Canvas.StrLen(currentText, xl, yl);
	Canvas.DrawColor = ColorBest;
	Canvas.SetPos(col1, y);
	Canvas.DrawText(currentText);
	y += yl + 2;

	ybox = y;
	OwnerInterface.Design.SetScoreboardFont(Canvas);
	if (LastTeamCasualty == -1)
		currentText = TextNone;
	else if (LastTeamCasualty == 0)
		currentText = TeamCasualties[0];
	else {
		currentText = TeamCasualties[0];
		for (i = 1; i <= LastTeamCasualty; i++)
			currentText = currentText $ ", " $ TeamCasualties[i];
		currentText = currentText @ "(" $ TextTotal @ string(LastTeamCasualty + 1) $ ")";
	}

	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col1t, y, col1twidth, xl, yl);
	if (ybox + oneline < y + yl) {
		OwnerInterface.Tool_DrawBox(Canvas, col1t, ybox, col1twidth, yl);
		y += yl;
	}
	else {
		y = ybox + oneline ;
		OwnerInterface.Tool_DrawBox(Canvas, col1t, ybox, col1twidth, y - ybox);
	}
	
	y += oneline;


	///////////////////////////////////
	// Draw Enemy Casualties
	///////////////////////////////////

	OwnerInterface.Design.SetHeadlineFont(Canvas);
	currentText = TextEnemyCasualties;
	Canvas.StrLen(currentText, xl, yl);
	Canvas.DrawColor = ColorWorse;
	Canvas.SetPos(col1, y);
	Canvas.DrawText(currentText);
	y += yl + 2;
	
	ybox = y;
	OwnerInterface.Design.SetScoreboardFont(Canvas);
	if (LastEnemyCasualty == -1)
		currentText = TextNone;
	else if (LastEnemyCasualty == 0)
		currentText = EnemyCasualties[0];
	else {
		currentText = EnemyCasualties[0];
		for (i = 1; i <= LastEnemyCasualty; i++)
			currentText = currentText $ ", " $ EnemyCasualties[i];
		currentText = currentText @ "(" $ TextTotal @ string(LastEnemyCasualty + 1) $ ")";
	}

	if (LastEnemyCasualty >= 64)
		OwnerInterface.Design.SetSmallFont(Canvas);

	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col1t, y, col1twidth, xl, yl);
	if (ybox + oneline * 6 < y + yl) {
		OwnerInterface.Tool_DrawBox(Canvas, col1t, ybox, col1twidth, yl);
		y += yl;
	}
	else {
		y = ybox + oneline * 6;
		OwnerInterface.Tool_DrawBox(Canvas, col1t, ybox, col1twidth, y - ybox);
	}

	y += oneline;
	OwnerInterface.Design.SetScoreboardFont(Canvas);

	///////////////////////////////////
	// Draw Estimated Opposing Forces
	///////////////////////////////////
	
	if (bUseSimpleEnemyAnalysis) {
		OwnerInterface.Design.SetHeadlineFont(Canvas);
		currentText = TextEnemyAnalysis;
		Canvas.StrLen(currentText, xl, yl);
		Canvas.DrawColor = ColorWorse;
		Canvas.SetPos(col1, y);
		Canvas.DrawText(currentText);
		y += yl + 2;

		CountEnemies(EnemiesSpawned, EnemiesAlive);
		
		OwnerInterface.Design.SetScoreboardFont(Canvas);
		currentText = TextEnemyInLevel $ ": " $ string(EnemiesSpawned);
		Canvas.DrawColor = ColorNormal;
		Tool_DrawText(Canvas, currentText, col1t, y, col1twidth2, xl, yl);

		OwnerInterface.Design.SetScoreboardFont(Canvas);
		currentText = TextEnemyRemaining $ ": " $ string(EnemiesAlive);
		Canvas.DrawColor = ColorNormal;
		Tool_DrawText(Canvas, currentText, col2t, y, col2twidth, xl, yl);
		OwnerInterface.Tool_DrawBox(Canvas, col1t, y, col1twidth, yl);
		y += yl;

		y += oneline;
	}
	else {
		OwnerInterface.Design.SetHeadlineFont(Canvas);
		currentText = TextEstimatedEnemies;
		Canvas.StrLen(currentText, xl, yl);
		Canvas.DrawColor = ColorWorse;
		Canvas.SetPos(col1, y);
		Canvas.DrawText(currentText);
		y += yl + 2;

		OwnerInterface.Design.SetScoreboardFont(Canvas);
		currentText = game.SinglePlayerDefinition.EstimatedEnemyForces;
		Canvas.DrawColor = ColorNormal;
		Tool_DrawText(Canvas, currentText, col1t, y, col1twidth, xl, yl);
		OwnerInterface.Tool_DrawBox(Canvas, col1t, y, col1twidth, yl);
		y += yl;	

		y += oneline;
	}

	///////////////////////
	// Draw Accuracy
	///////////////////////

	y2cols = y;

	OwnerInterface.Design.SetHeadlineFont(Canvas);
	currentText = TextAccuracy;
	Canvas.StrLen(currentText, xl, yl);
	Canvas.DrawColor = ColorBest;
	Canvas.SetPos(col1, y);
	Canvas.DrawText(currentText);
	y += yl + 2;

	ybox = y;

	OwnerInterface.Design.SetScoreboardFont(Canvas);
	currentText = TextShotsFired;
	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col1t, y, col1twidth2, xl, yl);
	currentText = string(game.SP_ShotsFired);
	Tool_DrawText(Canvas, currentText, col1t + col1twidth2 * 0.75, y, col1twidth2 * 0.25, xl, yl);
	y += yl;

	OwnerInterface.Design.SetScoreboardFont(Canvas);
	currentText = TextHeadshots;
	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col1t, y, col1twidth2, xl, yl);
	currentText = string(game.SP_EnemyHeadHits);
	Tool_DrawText(Canvas, currentText, col1t + col1twidth2 * 0.75, y, col1twidth2 * 0.25, xl, yl);
	y += yl;

	OwnerInterface.Design.SetScoreboardFont(Canvas);
	currentText = TextBodyHits;
	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col1t, y, col1twidth2, xl, yl);
	currentText = string(game.SP_EnemyBodyHits);
	Tool_DrawText(Canvas, currentText, col1t + col1twidth2 * 0.75, y, col1twidth2 * 0.25, xl, yl);
	y += yl;

	OwnerInterface.Design.SetScoreboardFont(Canvas);
	currentText = TextLegsHits;
	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col1t, y, col1twidth2, xl, yl);
	currentText = string(game.SP_EnemyLegsHits);
	Tool_DrawText(Canvas, currentText, col1t + col1twidth2 * 0.75, y, col1twidth2 * 0.25, xl, yl);
	y += yl;

	OwnerInterface.Design.SetScoreboardFont(Canvas);
	currentText = TextTeamHits;
	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col1t, y, col1twidth2, xl, yl);
	currentText = string(game.SP_ShotsHitFriendly);
	Tool_DrawText(Canvas, currentText, col1t + col1twidth2 * 0.75, y, col1twidth2 * 0.25, xl, yl);
	y += yl;

	OwnerInterface.Design.SetScoreboardFont(Canvas);
	currentText = TextMisses;
	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col1t, y, col1twidth2, xl, yl);
	currentText = string(game.SP_ShotsFired - game.SP_ShotsHitTarget);
	Tool_DrawText(Canvas, currentText, col1t + col1twidth2 * 0.75, y, col1twidth2 * 0.25, xl, yl);
	y += yl;

	OwnerInterface.Design.SetScoreboardFont(Canvas);
	currentText = TextOverall;
	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col1t, y, col1twidth2, xl, yl);

	if (game.SP_ShotsFired == 0) {
		Efficiency = -1;
		currentText = TextNoPercentage;
	}
	else {
		Efficiency = int(100 * float(game.SP_ShotsHitTarget) / float(game.SP_ShotsFired));
		currentText = string(Efficiency) $ " %";
	}
	if (Efficiency >= class'TO_GUITabDebriefing'.default.EfficiencyThreshold || Efficiency == -1)
		Canvas.DrawColor = ColorBest;
	else if (Efficiency <= 5)
		Canvas.DrawColor = ColorWorse;
	else
		Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col1t + col1twidth2 * 0.75, y, col1twidth2 * 0.25, xl, yl);
	y += yl;

	Canvas.DrawColor = ColorNormal;
	OwnerInterface.Tool_DrawBox(Canvas, col1t, ybox, col1twidth2, y - ybox);

	y = y2cols;

	///////////////////////
	// Draw player status
	///////////////////////

	OwnerInterface.Design.SetHeadlineFont(Canvas);
	currentText = TextPlayerStatus;
	Canvas.StrLen(currentText, xl, yl);
	Canvas.DrawColor = ColorBest;
	Canvas.SetPos(col2, y);
	Canvas.DrawText(currentText);
	y += yl + 2;

	ybox = y;

	OwnerInterface.Design.SetScoreboardFont(Canvas);
	Canvas.DrawColor = ColorNormal;
	if (game.Protagonist.PlayerReplicationInfo.Team == 1)
		currentText = TextConditionSF;
	else
		currentText = TextConditionTerr;
	Tool_DrawText(Canvas, currentText, col2t, y, col2twidth, xl, yl);
	if (game.Protagonist.health == -1) {
		if (game.Protagonist.PlayerReplicationInfo.Team == 1)
			currentText = TextPlayerDeadSF;
		else
			currentText = TextPlayerDeadTerr;
		Canvas.DrawColor = ColorWorse;
	}
	else {
		currentText = string(game.Protagonist.health) $ " HP";
		SetPercentageColor(Canvas, game.Protagonist.health);
	}
	Tool_DrawText(Canvas, currentText, col2t + col2twidth * 0.75, y, col2twidth * 0.25, xl, yl);
	y += yl;

	OwnerInterface.Design.SetScoreboardFont(Canvas);
	currentText = TextHeadshots;
	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col2t, y, col2twidth, xl, yl);
	if (game.SP_PlayerHeadHits == 0)
		Canvas.DrawColor = ColorBest;
	else
		Canvas.DrawColor = ColorWorse;
	currentText = string(game.SP_PlayerHeadHits);
	Tool_DrawText(Canvas, currentText, col2t + col2twidth * 0.75, y, col2twidth * 0.25, xl, yl);
	y += yl;

	OwnerInterface.Design.SetScoreboardFont(Canvas);
	currentText = TextBodyHits;
	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col2t, y, col2twidth, xl, yl);
	if (game.SP_PlayerBodyHits == 0)
		Canvas.DrawColor = ColorBest;
	else
		Canvas.DrawColor = ColorWorse;
	currentText = string(game.SP_PlayerBodyHits);
	Tool_DrawText(Canvas, currentText, col2t + col2twidth * 0.75, y, col2twidth * 0.25, xl, yl);
	y += yl;

	OwnerInterface.Design.SetScoreboardFont(Canvas);
	currentText = TextLegsHits;
	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col2t, y, col2twidth, xl, yl);
	if (game.SP_PlayerLegsHits == 0)
		Canvas.DrawColor = ColorBest;
	else
		Canvas.DrawColor = ColorWorse;
	currentText = string(game.SP_PlayerLegsHits);
	Tool_DrawText(Canvas, currentText, col2t + col2twidth * 0.75, y, col2twidth * 0.25, xl, yl);
	y += yl;


	OwnerInterface.Design.SetScoreboardFont(Canvas);
	currentText = TextRemainingHelmet;
	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col2t, y, col2twidth, xl, yl);
	currentText = string(game.Protagonist.HelmetCharge);
	SetPercentageColor(Canvas, game.Protagonist.HelmetCharge);
	Tool_DrawText(Canvas, currentText, col2t + col2twidth * 0.75, y, col2twidth * 0.25, xl, yl);
	y += yl;

	OwnerInterface.Design.SetScoreboardFont(Canvas);
	currentText = TextRemainingBody;
	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col2t, y, col2twidth, xl, yl);
	currentText = string(game.Protagonist.VestCharge);
	SetPercentageColor(Canvas, game.Protagonist.VestCharge);
	Tool_DrawText(Canvas, currentText, col2t + col2twidth * 0.75, y, col2twidth * 0.25, xl, yl);
	y += yl;

	OwnerInterface.Design.SetScoreboardFont(Canvas);
	currentText = TextRemainingLegs;
	Canvas.DrawColor = ColorNormal;
	Tool_DrawText(Canvas, currentText, col2t, y, col2twidth, xl, yl);
	currentText = string(game.Protagonist.LegsCharge);
	SetPercentageColor(Canvas, game.Protagonist.LegsCharge);
	Tool_DrawText(Canvas, currentText, col2t + col2twidth * 0.75, y, col2twidth * 0.25, xl, yl);
	y += yl;

	
	Canvas.DrawColor = ColorNormal;
	OwnerInterface.Tool_DrawBox(Canvas, col2t, ybox, col2twidth, y - ybox);

	y += oneline;

}

function CountEnemies(out int EnemiesSpawned, out int EnemiesAlive) {
	local Pawn					PawnLink;
	local LevelInfo				Level;

	Level = GetPlayerOwner().Level;

	if (game == none && Level == none) {
		EnemiesSpawned = -1;
		EnemiesAlive = -1;
		return;
	}

	for ( PawnLink=Level.PawnList; PawnLink!=None; PawnLink=PawnLink.nextPawn )	{
		if ( (PawnLink.PlayerReplicationInfo != None) && !PawnLink.PlayerReplicationInfo.bWaitingPlayer ) {
			if (s_Bot(PawnLink) != None && PawnLink.PlayerReplicationInfo.Team != game.SinglePlayerDefinition.Playerteam) {
				EnemiesSpawned++;
				if (!s_Bot(PawnLink).bNotPlaying)
					EnemiesAlive++;
			}

		}
	}

}

function SetPercentageColor(Canvas Canvas, int value) {
	if (value < 33)
		Canvas.DrawColor = ColorWorse;
	else if (value < 100)
		Canvas.DrawColor = ColorNormal;
	else
		Canvas.DrawColor = ColorBest;
}


///////////////////////////////////////
// defaultproperties
///////////////////////////////////////

defaultproperties
{
     LastEnemyCasualty=-1
     LastTeamCasualty=-1
     TextTitle="Mission Status"
     TextHint="This screen displays the status of mission in progress."
     TextFriendlyCasualties="Friendly Casualties"
     TextEnemyCasualties="Enemy Casualties"
     TextEstimatedEnemies="Estimated Enemy Forces"
     TextEnemyAnalysis="Enemy Forces Analysis"
     TextEnemyInLevel="Enemies in surroundings"
     TextEnemyRemaining="Enemies remaining"
     TextNone="None"
     TextTotal="Total of"
     TextNoPercentage="N/A"
     TextAccuracy="Accuracy"
     TextShotsFired="Shots fired:"
     TextHeadshots="Head hits:"
     TextBodyHits="Body hits:"
     TextLegsHits="Lower body hits:"
     TextTeamHits="Friendly hits:"
     TextMisses="Misses:"
     TextOverall="Overall Accuracy:"
     TextPlayerStatus="Player Status"
     TextConditionSF="Agent's condition:"
     TextConditionTerr="Operative's condition:"
     TextRemainingHelmet="Helmet condition:"
     TextRemainingBody="Body armor condition:"
     TextRemainingLegs="Legs armor condition:"
     TextPlayerDeadSF="KIA"
     TextPlayerDeadTerr="Dead"
}
